@@ -98,6 +98,32 @@ function createLink (si, si_target, passthrough, exclusive)
     return
   end
 
+  si_link:connect("link-error", function (_, error_msg)
+    local ids = {si_id}
+    if si_flags[si_id] ~= nil then
+      table.insert (ids, si_flags[si_id].peer_id)
+    end
+
+    for _, id in ipairs (ids) do
+      local si = linkables_om:lookup {
+        Constraint { "id", "=", id, type = "gobject" },
+      }
+      if si then
+        local node = si:get_associated_proxy ("node")
+        local client_id = node.properties["client.id"]
+        if client_id then
+          local client = clients_om:lookup {
+            Constraint { "bound-id", "=", client_id, type = "gobject" }
+          }
+          if client then
+            Log.info (node, "sending client error: " .. error_msg)
+            client:send_error (node["bound-id"], -32, error_msg)
+          end
+        end
+      end
+    end
+  end)
+
   -- register
   si_flags[si_id].peer_id = si_target.id
   si_flags[si_id].failed_peer_id = si_target.id
@@ -744,10 +770,7 @@ function handleLinkable (si)
     Log.info (si, "... target not found, reconnect:" .. tostring(reconnect))
 
     local node = si:get_associated_proxy ("node")
-    if not reconnect then
-      Log.info (si, "... destroy node")
-      node:request_destroy()
-    elseif si_flags[si.id].was_handled then
+    if reconnect and si_flags[si.id].was_handled then
       Log.info (si, "... waiting reconnect")
       return
     end
@@ -757,9 +780,20 @@ function handleLinkable (si)
       local client = clients_om:lookup {
         Constraint { "bound-id", "=", client_id, type = "gobject" }
       }
-      if client then
-        client:send_error(node["bound-id"], -2, "no node available")
+      local message
+      if reconnect then
+        message = "no target node available"
+      else
+        message = "target not found"
       end
+      if client then
+        client:send_error(node["bound-id"], -2, message)
+      end
+    end
+
+    if not reconnect then
+      Log.info (si, "... destroy node")
+      node:request_destroy()
     end
   else
     createLink (si, si_target, can_passthrough, exclusive)
